Skip to contentSkip to conversation

Slow I/O with LUKS on amd64

dm-crypt Hanno Foest 1 participant 1 message Mar 15, 2011

lore
Share & tools
lore
#0 lore raw
Quoted 2 lines · Thomas Damgaard

I have recently switched from i386 to amd64. After switching to 64 bit, I/O on LUKS encrypted devices became horribly slow.

I had the same issue with Ubuntu 10.10. After installing a kernel from the upcoming 11.04, doing a 'time /usr | wc -l' went from 3 minutes to 6 seconds. And yes, I dropped my caches. :)

I installed the following image, BTW:
//launchpadlibrarian.net/65900455/linux-image-2.6.38-6-generic_2.6.38-6.34_amd64.deb

Hanno